changeset 101270:652c25392003

(eldoc-minor-mode-string, eldoc-message-commands) (eldoc-print-current-symbol-info): Doc fix (consistent case of "ElDoc").
author Glenn Morris <rgm@gnu.org>
date Sat, 17 Jan 2009 20:01:17 +0000
parents 95bf8f22378a
children c7dad4ac139c
files lisp/emacs-lisp/eldoc.el
diffstat 1 files changed, 6 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/emacs-lisp/eldoc.el	Sat Jan 17 19:22:59 2009 +0000
+++ b/lisp/emacs-lisp/eldoc.el	Sat Jan 17 20:01:17 2009 +0000
@@ -41,7 +41,7 @@
 ;;      (add-hook 'lisp-interaction-mode-hook 'turn-on-eldoc-mode)
 ;;      (add-hook 'ielm-mode-hook 'turn-on-eldoc-mode)
 
 ;; Major modes for other languages may use Eldoc by defining an
 ;; appropriate function as the buffer-local value of
 ;; `eldoc-documentation-function'.
 
@@ -65,7 +65,7 @@
 
 ;;;###autoload
 (defcustom eldoc-minor-mode-string " ElDoc"
-  "String to display in mode line when Eldoc Mode is enabled; nil for none."
+  "String to display in mode line when ElDoc Mode is enabled; nil for none."
   :type '(choice string (const :tag "None" nil))
   :group 'eldoc)
 
@@ -124,19 +124,21 @@
 (defconst eldoc-message-commands
   (make-vector eldoc-message-commands-table-size 0)
   "Commands after which it is appropriate to print in the echo area.
-Eldoc does not try to print function arglists, etc., after just any command,
+ElDoc does not try to print function arglists, etc., after just any command,
 because some commands print their own messages in the echo area and these
 functions would instantly overwrite them.  But `self-insert-command' as well
 as most motion commands are good candidates.
 This variable contains an obarray of symbols; do not manipulate it
 directly.  Instead, use `eldoc-add-command' and `eldoc-remove-command'.")
 
+;; Not a constant.
 (defconst eldoc-last-data (make-vector 3 nil)
   "Bookkeeping; elements are as follows:
   0 - contains the last symbol read from the buffer.
   1 - contains the string last displayed in the echo area for variables,
       or argument string for functions.
   2 - 'function if function args, 'variable if variable documentation.")
+
 (defvar eldoc-last-message nil)
 
 (defvar eldoc-timer nil "ElDoc's timer object.")
@@ -254,7 +256,7 @@
 effect.
 
 This variable is expected to be made buffer-local by modes (other than
-Emacs Lisp mode) that support Eldoc.")
+Emacs Lisp mode) that support ElDoc.")
 
 (defun eldoc-print-current-symbol-info ()
   (condition-case err
@@ -41,7 +41,7 @@
 ;;      (add-hook 'ielm-mode-hook 'turn-on-eldoc-mode)
 
-;; Major modes for other languages may use Eldoc by defining an
+;; Major modes for other languages may use ElDoc by defining an
 ;; appropriate function as the buffer-local value of
 ;; `eldoc-documentation-function'.